<?php
/**
 * Webkul MarketingCloud Magento Connector SyncAllCategory Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Category;

use Magento\Backend\App\Action;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Framework\Controller\ResultFactory;

class SyncAllCategory extends \Magento\Backend\App\Action
{
    /**
     * @var \Magento\Backend\Model\View\Result\Forward
     */
    protected $_filter;
    protected $_resultForwardFactory;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
     */
    public function __construct(
        Filter $filter,
        \Magento\Backend\App\Action\Context $context,
        \Magento\Catalog\Model\Category $categoryModel,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
    ) {
        parent::__construct($context);
        $this->_filter = $filter;
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_categoryModel = $categoryModel;
        $this->_messageManager = $messageManager;
        $this->_resultForwardFactory = $resultForwardFactory;
    }

    /**
     * Forward to edit
     *
     * @return \Magento\Backend\Model\View\Result\Forward
     */
    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if (isset($token) && $token != null) {
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            return $resultRedirect->setPath('adminhtml/system_config/edit/section/marketingcloudmagentoconnector');
        }
        $storeId = (int) $this->getRequest()->getParam('store', 0);
        $limit = $this->_scopeConfig->getValue('marketingcloud/batch/mc_batch_cat') ?? '10';
        $exportIds = [];
        $helper = $this->_connection;
        $collection = $this->_categoryModel->getCollection()
                                        ->addAttributeToFilter('level', ['neq' => 0], 'is_active', '1')
                                        ->addAttributeToSelect('entity_id');

        $res = $helper->getAutoSyncAllCategory($collection);
        $exportIds = $collection->getAllIds();

        if (count($collection) == 0) {
            $this->_messageManager->addSuccess(__("No Category are exist at Magento."));
        } else {
            if (count($exportIds) == 0) {
                $this->_messageManager->addSuccess(__("All Magento Category are exported Successfully!!"));
            } else {
                $this->_messageManager->addSuccess(__("All Magento Category are exported Successfully!!"));
            }
        }

        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return  $resultRedirect->setPath('catalog/product/', ['store' => $storeId]);
    }
}
