<?php
/**
 * Webkul MarketingCloudMagentoConnector Product Edit Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Product;

class ExportAllIds extends \Magento\Backend\App\Action
{
    /**
     * @var \Magento\Backend\Model\View\Result\Forward
     */
    protected $_resultForwardFactory;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Catalog\Model\Product $productModel,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
    ) {
        $this->_productModel = $productModel;
        $this->_connection = $connection;
        $this->_messageManager = $messageManager;
        $this->_scopeConfig = $scopeConfig;
        $this->_resultForwardFactory = $resultForwardFactory;
        parent::__construct($context);
    }

    /**
     * Forward to edit
     *
     * @return \Magento\Backend\Model\View\Result\Forward
     */
    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if(isset($token) && $token != null){
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            return $resultRedirect->setPath('adminhtml/system_config/edit/section/marketingcloudmagentoconnector');
        }
        $storeId = (int) $this->getRequest()->getParam('store', 0);
        $exportIds = [];
        $helper = $this->_connection;
        $mapTemplates = [];
        $collection = $this->_productModel->getCollection()
                                        ->addAttributeToFilter('type_id', ['neq' => 'configurable'])
                                        ->addAttributeToSelect('entity_id');
        $helper->getSyncProduct($collection);

        if (count($collection) == 0) {
            $this->messageManager->addSuccess(__("No Products are exist at Magento."));
        } else {
            if (count($exportIds) == 0) {
                $this->messageManager->addSuccess(__("All Magento Products are already exported at Odoo."));
            }
        }

        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return  $resultRedirect->setPath('catalog/*/', ['store' => $storeId]);
    }
}
